@@ -393,17 +393,13 @@ class DQNLightning(pl.LightningModule):
                             help="how many frames do we update the target network")
         parser.add_argument("--replay_size", type=int, default=1000,
                             help="capacity of the replay buffer")
-        parser.add_argument("--warm_start_size", type=int, default=1000,
+        parser.add_argument("--warm_start_steps", type=int, default=1000,
                             help="how many samples do we use to fill our buffer at the start of training")
         parser.add_argument("--eps_last_frame", type=int, default=1000,
                             help="what frame should epsilon stop decaying")
         parser.add_argument("--eps_start", type=float, default=1.0, help="starting value of epsilon")
         parser.add_argument("--eps_end", type=float, default=0.01, help="final value of epsilon")
         parser.add_argument("--episode_length", type=int, default=200, help="max length of an episode")
-        parser.add_argument("--max_episode_reward", type=int, default=200,
-                            help="max episode reward in the environment")
-        parser.add_argument("--warm_start_steps", type=int, default=1000,
-                            help="max episode reward in the environment")
         return parser
 
 
@@ -424,7 +420,7 @@ if __name__ == '__main__':
     torch.manual_seed(0)
     np.random.seed(0)
 
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(add_help=False)
     parser = DQNLightning.add_model_specific_args(parser)
     args = parser.parse_args()
 
