@@ -17,7 +17,6 @@ from typing import Any, Callable, Optional, Union
 import torch
 from torch.optim.lr_scheduler import _LRScheduler
 
-from pytorch_lightning import _logger as log
 from pytorch_lightning.accelerators.accelerator import Accelerator, ReduceOp
 from pytorch_lightning.cluster_environments import ClusterEnvironment
 from pytorch_lightning.utilities import AMPType, HOROVOD_AVAILABLE
@@ -104,8 +103,7 @@ class HorovodAccelerator(Accelerator):
                 # Synchronization will be performed explicitly following backward()
                 stack.enter_context(optimizer.skip_synchronize())
 
-            # set up training routine
-            self.trainer.train_loop.setup_training(self.trainer.model)
+            self.trainer.setup_trainer(self.trainer.model)
 
             # train or test
             results = self.train_or_test()
