@@ -16,6 +16,7 @@
 
 import cProfile
 import io
+import logging
 import os
 import pstats
 import time
@@ -27,9 +28,10 @@ from typing import Optional, Union
 import fsspec
 import numpy as np
 
-from pytorch_lightning import _logger as log
 from pytorch_lightning.utilities.cloud_io import get_filesystem
 
+log = logging.getLogger(__name__)
+
 
 class BaseProfiler(ABC):
     """
